@@ -5,7 +5,8 @@
   global $notPartOfDomainName, $numberOfDotSections, $useSessionBased,
          $putHostNameOnFrontOfUsername, $checkByExcludeList,
          $at, $dot, $dontUseHostName, $perUserSettingsFile,
-         $smHostIsDomainThatUserLoggedInWith, $virtualDomains,
+         $smHostIsDomainThatUserLoggedInWith, 
+         $useDomainFromServerEnvironment, $virtualDomains,
          $sendmailVirtualUserTable, $virtualDomainDataDir,
          $allVirtualDomainsAreUnderOneHost, $vlogin_debug, $removeFromFront,
          $chopOffDotSectionsFromRight, $chopOffDotSectionsFromLeft,
@@ -15,7 +16,11 @@
          $securePort, $useDomainFromVirtDomainsArray,
          $usernameDomainIsHost, $stripDomainFromUserSubstitution,
          $serviceLevelBackend, $internalServiceLevelFile,
-         $vlogin_dsn, $sqlServiceLevelQuery;
+         $vlogin_dsn, $sqlServiceLevelQuery, $SQLDatabaseDomainLookup,
+         $SQLDatabaseUserLookup, $SQLDatabaseServiceLevelLookup,
+         $default_org_logo, $rawLoginIsOutgoingEmailAddress,
+         $dontUseHostNameUserList, $always_prepend, $always_append,
+         $IMAPServerRules, $SMTPServerRules;
 
 
   // list of domain-specific attributes (note that each domain is 
@@ -57,4 +62,3 @@
   $vlogin_debug = 0;
 
 
-?>
