@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Login Manager Plugin
-  * Copyright (C) 2003-2006 Paul Lesneiwski <paul@squirrelmail.org>
+  * Copyright (C) 2003-2007 Paul Lesneiwski <paul@squirrelmail.org>
   * This program is licensed under GPL. See COPYING for details
   *
   */
@@ -63,6 +63,9 @@ function SQL_settings_lookup($query, $replacement, $args)
    }
 
 
+   $already_enabled = array();
+
+
    // override any settings found
    //
    foreach ($settings as $settingPair)
@@ -139,10 +142,12 @@ function SQL_settings_lookup($query, $replacement, $args)
          //
          else if (stristr($setting, 'enable_plugins'))
          {
+            $already_enabled = $value;
             foreach ($value as $pluginName)
             {
-               $plugins[] = $pluginName;
-               use_plugin($pluginName);
+               // function is found in Compatibility plugin v2.0.5+
+               //
+               add_plugin($pluginName, $args);
             }
          }
 
@@ -151,16 +156,41 @@ function SQL_settings_lookup($query, $replacement, $args)
          //
          else if (stristr($setting, 'disable_plugins'))
          {
-            foreach ($value as $pluginName)
+            // disable ALL plugins?
+            //
+            if (in_array('*', $value))
             {
-               $pluginKey = array_search($pluginName, $plugins);
-               if (!is_null($pluginKey) && $pluginKey !== FALSE)
+               $reenable_vlogin = FALSE;
+               $reenable_multilogin = FALSE;
+               if (in_array('vlogin', $plugins))
+                  $reenable_vlogin = TRUE;
+               if (in_array('multilogin', $plugins))
+                  $reenable_multilogin = TRUE;
+
+               $plugins = array();
+               $squirrelmail_plugin_hooks = array();
+
+               // if we had already enabled some plugins,
+               // reenable them again
+               //
+               foreach ($already_enabled as $pluginName)
+                  add_plugin($pluginName, $args, TRUE);
+
+               if ($reenable_multilogin)
+                  add_plugin('multilogin', $args, TRUE);
+               if ($reenable_vlogin)
+                  add_plugin('vlogin', $args, TRUE);
+            }
+
+            // no, just disable some plugins...
+            //
+            else
+            {
+               foreach ($value as $pluginName)
                {
-                  unset($plugins[$pluginKey]);
-                  foreach (array_keys($squirrelmail_plugin_hooks) as $hookName)
-                  {
-                     unset($squirrelmail_plugin_hooks[$hookName][$pluginName]);
-                  }
+                  // function is found in Compatibility plugin v2.0.5+
+                  //
+                  remove_plugin($pluginName);
                }
             }
          }
@@ -194,4 +224,3 @@ function SQL_settings_lookup($query, $replacement, $args)
 
 
 
-?>
